CoordinationConfig class

Meta config collection for the whole library.

Implemented types

Constructors

CoordinationConfig({String name = 'peer_coordinator', CoordinationSessionConfig? sessionConfig, CoordinationStreamConfig? streamConfig, List<NetworkStreamConfig>? initialStreamConfigs, TopologyConfig? topologyConfig, required ITransportConfig transportConfig})

Properties

description → String?
Returns a description of the identity.
no setteroverride
hashCode → int
The hash code for this object.
no setteroverride
id → String
Returns a unique identifier for the identity.
no setteroverride
initialStreamConfigs → List<NetworkStreamConfig>?
final
name → String
The name of the coordination configuration.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sessionConfig ↔ CoordinationSessionConfig
latefinal
streamConfig ↔ CoordinationStreamConfig
latefinal
topologyConfig → TopologyConfig
final
transportConfig → ITransportConfig
final

Methods

copyWith({String? name, CoordinationSessionConfig? sessionConfig, CoordinationStreamConfig? streamConfig, List<NetworkStreamConfig>? initialStreamConfigs, TopologyConfig? topologyConfig, ITransportConfig? transportConfig}) → CoordinationConfig
Creates a copy with modified values
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
Converts the object to a map representation for serialization.
override
toString() → String
A string representation of this object.
override
validate({bool throwOnError = false}) → bool
Validates the configuration
override

Operators

operator ==(Object other) → bool
The equality operator.
override