IJoinable class abstract interface

Interface for classes that can join and leave.

Implementers

Properties

hashCode → int
The hash code for this object.
no setterinherited
joined → bool
Indicates whether the IJoinable is currently joined.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

join() → FutureOr<void>
Join
leave() → FutureOr<void>
Leaves
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited