ILifecycle class abstract interface

Interface for managing the lifecycle of an object.

Implementers

Properties

created → bool
Indicates whether the ILifecycle implementation has been created.
no setter
disposed → bool
Indicates whether the ILifecycle implementation has been disposed.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

create() → FutureOr<void>
Creates.
dispose() → FutureOr<void>
Disposes the ILifecycle implementation, releasing any resources.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited