LatencyWindow class final

The last few arrival latencies of a stream at one node: their mean and spread, for ClockHop.latency and ClockHop.jitter. Also used for the times samples waited there, for ClockHop.held.

Constructors

LatencyWindow([int size = 256])

Properties

hashCode → int
The hash code for this object.
no setterinherited
jitter → double?
Standard deviation of what is held, or null when empty.
no setter
mean → double?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

add(double latency) → void
clear() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited