timestamp property

  1. @override
DateTime timestamp
final

Returns a timestamp for the object. This is intentionally generic, as it is not always going to be something specific like a creation time or modification time.

Implementation

@override
final DateTime timestamp;