joinTimeout property
Duration
get
joinTimeout
How long to allow for a join to settle.
Implementation
Duration get joinTimeout => const Duration(seconds: 3);
How long to allow for a join to settle.
Duration get joinTimeout => const Duration(seconds: 3);