transportConfigFor abstract method
A transport config for one node. All nodes in a run must end up on the same medium.
Implementation
ITransportConfig transportConfigFor(int nodeIndex);
A transport config for one node. All nodes in a run must end up on the same medium.
ITransportConfig transportConfigFor(int nodeIndex);