identityConflict constant
int
const identityConflict
The claimed endpoint or identity belongs to another live connection.
Implementation
static const int identityConflict = 4409;
The claimed endpoint or identity belongs to another live connection.
static const int identityConflict = 4409;