policyViolation constant
int
const policyViolation
A limit was exceeded: frame too large, too many endpoints, too many queries, hub full.
Implementation
static const int policyViolation = 4413;
A limit was exceeded: frame too large, too many endpoints, too many queries, hub full.
static const int policyViolation = 4413;