sessionClosed constant
int
const sessionClosed
The session has ended, or this node was revoked. Do not retry.
Implementation
static const int sessionClosed = 4403;
The session has ended, or this node was revoked. Do not retry.
static const int sessionClosed = 4403;