WsFrame class

A control frame.

Constructors

WsFrame(WsControl type, Map<String, dynamic> payload)
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
payload → Map<String, dynamic>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → WsControl
final

Methods

encode() → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

decode(String text) → WsFrame
Parses a control frame.