WsInbound class

A relayed message addressed to one of this node's endpoints.

Constructors

WsInbound({required String streamName, required String fromEndpointId, required Object payload})
const

Properties

fromEndpointId → String
final
hashCode → int
The hash code for this object.
no setterinherited
payload → Object
A JSON-decoded map for control messages, or a Uint8List sample frame.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
streamName → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited