maxEndpointsPerConnection property
Endpoints one connection may register. A node holds one for its coordination stream plus one per data stream.
Implementation
final int maxEndpointsPerConnection;
Endpoints one connection may register. A node holds one for its coordination stream plus one per data stream.
final int maxEndpointsPerConnection;