pingInterval property
WebSocket ping interval. Without this a half-open socket holds its endpoint ids, slot and routes until the OS notices, which may be never.
Implementation
final Duration pingInterval;
WebSocket ping interval. Without this a half-open socket holds its endpoint ids, slot and routes until the OS notices, which may be never.
final Duration pingInterval;