data
library
Classes
-
ClockSyncSample
-
One clock-offset estimate for one peer, as the transport measured it.
-
CoordinationStream<T extends CoordinationStreamConfig, M extends StringMessage>
-
A coordination stream used for network coordination tasks.
-
CoordinationStreamConfig
-
Configuration for a coordination stream used for network coordination tasks.
-
CoordinationStreamConfigFactory
-
Factory for creating coordination stream configurations.
-
DataStream<T extends DataStreamConfig, M extends IMessage<IMessageType>>
-
A data stream used for transmitting actual data samples.
-
DataStreamConfig
-
-
DataStreamConfigFactory
-
-
Double64Mapping
-
Implementation of a IMessageType for double64 data.
-
Float32Mapping
-
Implementation of a IMessageType for float32 data.
-
Int16Mapping
-
Implementation of a IMessageType for int16 data.
-
Int32Mapping
-
Implementation of a IMessageType for int32 data.
-
Int64Mapping
-
Implementation of a IMessageType for int64 data.
-
Int8Mapping
-
implementation of a IMessageType for int8 data.
-
IntMessageTypeMapping
-
-
Message<D, M extends MessageTypeMapping<D>, T extends MessageType<D, M>>
-
Implementation of a message with specific data and type.
-
MessageFactory
-
Factory for creating messages of various types.
-
MessageTiming
-
Receive-side timing for a single message, as the transport observed it.
-
MessageType<T, M extends MessageTypeMapping<T>>
-
Generic reusable message type wrapper for a specific data type Type and
MessageTypeMapping.
-
MessageTypeMapping<T>
-
Base mapping class for message types.
-
NetworkStream<T extends NetworkStreamConfig, M extends IMessage<IMessageType>>
-
Configuration for a coordination session used to manage network nodes.
-
NetworkStreamConfig
-
Base class for all network stream configurations.
-
NetworkStreamFactory<TSession extends CoordinationSession>
-
Creates network streams.
-
PeerClock
-
A process-local monotonic clock, mirroring the contract of LSL's
lsl_local_clock().
-
StringMapping
-
implementation of a IMessageType for string data.
Typedefs
-
Double64Message
= Message<double, Double64Mapping, MessageType<double, Double64Mapping>>
-
Double64 Message type alias with Double64Mapping and Double MessageType.
-
Float32Message
= Message<double, Float32Mapping, MessageType<double, Float32Mapping>>
-
Float32 Message type alias with Float32Mapping and Double MessageType.
-
Int16Message
= Message<int, Int16Mapping, MessageType<int, Int16Mapping>>
-
Int16 Message type alias with Int16Mapping and Int MessageType.
-
Int32Message
= Message<int, Int32Mapping, MessageType<int, Int32Mapping>>
-
Int32 Message type alias with Int32Mapping and Int MessageType.
-
Int64Message
= Message<int, Int64Mapping, MessageType<int, Int64Mapping>>
-
Int64 Message type alias with Int64Mapping and Int MessageType.
-
Int8Message
= Message<int, Int8Mapping, MessageType<int, Int8Mapping>>
-
Int8 Message type alias with Int8Mapping and Int MessageType.
-
StringMessage
= Message<String, StringMapping, MessageType<String, StringMapping>>
-
String Message type alias, with StringMapping and String MessageType.