MessageFactory class
Factory for creating messages of various types.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
double64Message(
{String? uId, required IList< double> data, int channels = 1, DateTime? timestamp, MessageTiming? timing}) → Double64Message -
Creates a new Double64Message with the given parameters.
The
channelsparameter specifies the number of channels in the message. Thedataparameter must be a list of doubles with length equal tochannels. TheuIdparameter is optional and will be generated if not provided. Thetimestampparameter is optional and will be set to the current time if not provided. -
float32Message(
{String? uId, required IList< double> data, int channels = 1, DateTime? timestamp, MessageTiming? timing}) → Float32Message -
Creates a new Float32Message with the given parameters.
The
channelsparameter specifies the number of channels in the message. Thedataparameter must be a list of doubles with length equal tochannels. TheuIdparameter is optional and will be generated if not provided. Thetimestampparameter is optional and will be set to the current time if not provided. -
int16Message(
{String? uId, required IList< int> data, int channels = 1, DateTime? timestamp, MessageTiming? timing}) → Int16Message -
Creates a new Int16Message with the given parameters.
The
channelsparameter specifies the number of channels in the message. Thedataparameter must be a list of integers with length equal tochannels. Each integer must be in the range -32768 to 32767. TheuIdparameter is optional and will be generated if not provided. Thetimestampparameter is optional and will be set to the current time if not provided. -
int32Message(
{String? uId, required IList< int> data, int channels = 1, DateTime? timestamp, MessageTiming? timing}) → Int32Message -
Creates a new Int32Message with the given parameters.
The
channelsparameter specifies the number of channels in the message. Thedataparameter must be a list of integers with length equal tochannels. Each integer must be in the range -2147483648 to 2147483647. TheuIdparameter is optional and will be generated if not provided. Thetimestampparameter is optional and will be set to the current time if not provided. -
int64Message(
{String? uId, required IList< int> data, int channels = 1, DateTime? timestamp, MessageTiming? timing}) → Int64Message -
Creates a new Int64Message with the given parameters.
The
channelsparameter specifies the number of channels in the message. Thedataparameter must be a list of integers with length equal tochannels. Each integer must be in the range -9223372036854775808 to 9223372036854775807. TheuIdparameter is optional and will be generated if not provided. Thetimestampparameter is optional and will be set to the current time if not provided. -
int8Message(
{String? uId, required IList< int> data, int channels = 1, DateTime? timestamp, MessageTiming? timing}) → Int8Message -
Creates a new Int8Message with the given parameters.
The
channelsparameter specifies the number of channels in the message. Thedataparameter must be a list of integers with length equal tochannels. Each integer must be in the range -128 to 127. TheuIdparameter is optional and will be generated if not provided. Thetimestampparameter is optional and will be set to the current time if not provided. -
stringMessage(
{String? uId, required IList< String> data, int channels = 1, DateTime? timestamp, MessageTiming? timing}) → StringMessage -
Creates a new StringMessage with the given parameters.
The
channelsparameter specifies the number of channels in the message. Thedataparameter must be a list of strings with length equal tochannels. TheuIdparameter is optional and will be generated if not provided. Thetimestampparameter is optional and will be set to the current time if not provided.