WsPeerHandle class
A peer the hub told us about.
- Inheritance
-
- Object
- ManagedResource
- WsPeerHandle
- Implemented types
Constructors
- WsPeerHandle(PeerDescriptor descriptor, {int? slot, IResourceManager? manager})
Properties
- created → bool
-
Indicates whether the ILifecycle implementation has been created.
no setterinherited
- description → String?
-
Returns a description of the identity.
no setterinherited
- descriptor → PeerDescriptor
-
What was discovered.
final
- disposed → bool
-
Indicates whether the ILifecycle implementation has been disposed.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Returns a unique identifier for the identity.
finalinherited
- manager → IResourceManager?
-
gets the resource manager that manages this resource
no setterinherited
- name → String
-
Returns a human-readable name for the identity.
no setterinherited
- ownedByDiscovery → bool
-
Whether the discovery instance still owns (and will free) the underlying
resource.
no setteroverride
- rawUnsafe → Object?
-
The transport's private payload — an
LSLStreamInfofor LSL, a connection id for a hub transport.no setteroverride - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shadowUId ↔ String?
-
getter/setter pairinherited
- slot → int?
-
The hub's numeric id for this endpoint, used in binary sample frames.
final
- taken → bool
-
Whether take has already been called.
no setteroverride
- uId → String
-
Returns a unique identifier that is guaranteed to be globally unique.
no setterinherited
Methods
-
create(
) → FutureOr< void> -
Marks the resource created.
inherited
-
dispose(
) → FutureOr< void> -
Disposes the ILifecycle implementation, releasing any resources.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
take(
) → void -
Detaches from the discovery manager, transferring ownership to the caller.
override
-
toString(
) → String -
A string representation of this object.
inherited
-
updateManager(
IResourceManager? newManager) → void -
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited